@@ -20,7 +20,7 @@ use OTRS::OPM::Maker -command;
 use OTRS::OPM::Maker::Utils::OTRS3;
 use OTRS::OPM::Maker::Utils::OTRS4;
 
-our $VERSION = 1.33;
+our $VERSION = 1.34;
 
 sub abstract {
     return "build sopm file based on metadata";
@@ -229,6 +229,8 @@ sub execute {
         ColumnChange     => \&_ColumnChange,
         ForeignKeyCreate => \&_ForeignKeyCreate,
         ForeignKeyDrop   => \&_ForeignKeyDrop,
+        UniqueDrop       => \&_UniqueDrop,
+        UniqueCreate     => \&_UniqueCreate,
     );
     
     my %tables_to_delete;
@@ -521,6 +523,47 @@ sub _ForeignKeyDrop {
     return $string;
 }
 
+sub _UniqueCreate {
+    my ($action) = @_;
+
+    my $table   = $action->{name};
+    my $version = $action->{version};
+
+    my $version_string = $version ? ' Version="' . $version . '"' : '';
+
+    my $string = '        <TableAlter Name="' . $table . '"' . $version_string . ">\n";
+    $string   .= sprintf qq~            <UniqueCreate Name="%s">\n~, $action->{unique_name};
+
+    COLUMN:
+    for my $column ( @{ $action->{columns} || [] } ) {
+        $string .= sprintf qq~                <UniqueColumn Name="%s" />\n~,
+            $column;
+    }
+
+    $string .= qq~            </UniqueCreate>\n~;
+    $string .= '        </TableAlter>';
+
+    return $string;
+}
+
+sub _UniqueDrop {
+    my ($action) = @_;
+
+    my $table   = $action->{name};
+    my $version = $action->{version};
+
+    my $version_string = $version ? ' Version="' . $version . '"' : '';
+
+    my $string = '        <TableAlter Name="' . $table . '"' . $version_string . ">\n";
+
+    $string .= sprintf qq~            <UniqueDrop Name="%s" />\n~,
+        $action->{unique_name};
+
+    $string .= '        </TableAlter>';
+
+    return $string;
+}
+
 sub _ColumnChange {
     my ($action) = @_;
 
@@ -583,7 +626,7 @@ OTRS::OPM::Maker::Command::sopm - Build .sopm file based on metadata
 
 =head1 VERSION
 
-version 1.33
+version 1.34
 
 =head1 DESCRIPTION
 
